pub struct MessageQueue { /* private fields */ }Implementations
Sourceimpl MessageQueue
impl MessageQueue
Sourcepub fn has<M: Message>(&self) -> bool
pub fn has<M: Message>(&self) -> bool
Returns true if a message of type M is in the queue.
Example
use agape::MessageQueue;
let mut messages = MessageQueue::new();
messages.add(String::new());
assert!(messages.has::<String>());pub fn add<M: Message>(&mut self, item: M)
pub fn set<M: Message>(&mut self, item: M)
Sourcepub fn remove<M: 'static>(&mut self) -> Option<M>
pub fn remove<M: 'static>(&mut self) -> Option<M>
Remove and return a message of type M from the queue.
pub fn remove_index(&mut self, index: usize)
Sourcepub fn get<T: 'static>(&self) -> Option<&T>
pub fn get<T: 'static>(&self) -> Option<&T>
Get a message from the message queue.
use agape::MessageQueue;
#[derive(Debug,Copy, Clone)]
struct DummyMessage;
let mut message_queue = MessageQueue::new();
message_queue.add(DummyMessage);
assert!(message_queue.get::<DummyMessage>().is_some())pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool