Position

Struct Position 

#[repr(C)]
pub struct Position { pub x: f32, pub y: f32, }
The x and y position of any structure.

You can add and subtract Positions’s to and from each other

use agape_core::Position;

let mut position = Position::new(200.0,200.0);
position -= Position::unit(50.0);
assert_eq!(position.x,150.0);

position += Position::unit(120.0);
assert_eq!(position.y,270.0);

You can also add and subtract arbitrary floats to and from Position’s

use agape_core::Position;

let mut position = Position::new(200.0,200.0);
position += 55.0;
assert_eq!(position.x,255.0);

position -= 25.0;
assert_eq!(position.y,230.0);

Fields

x: f32y: f32

Implementations

Source

impl Position

pub fn new(x: f32, y: f32) -> Position

pub fn translate(&mut self, x: f32, y: f32)

Translate the position by x and y amount.

Example
use agape_core::Position;

let mut position = Position::new(0.0,0.0);
position.translate(40.0,100.0);

assert_eq!(Position::new(40.0,100.0),position);
pub fn set(&mut self, x: f32, y: f32)

Set the position

pub fn unit(value: f32) -> Position

Creates a Position where both the x and y are a single value.

Example
use agape_core::Position;

let position = Position::unit(500.0);

assert_eq!(position.x,position.y);
assert_eq!(position.x,500.0);